/**
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <glib/gprintf.h>

#include <libxfce4util/libxfce4util.h>

#include "services.h"

static void
usage ()
{
    g_printf("Usage:\n"
             "services-blacklist help|list|add|del [services]\n"
             "   help: show this message\n"
             "   list: display the blacklisted services\n"
             "   add : add the listed service(s) to the blacklist\n"
             "   del : delete the listed service(s) from the blacklist\n");
}

static void
print_item (gpointer a, gpointer b)
{
    g_printf (" %s\n", (gchar *) a);
}

int main (int argc, gchar **argv)
{
    static gboolean noaction = FALSE;
    GList *blacklist;
    int i;

    static GOptionEntry entries[] =
    {
        { "no-action", 'n', 0, G_OPTION_ARG_NONE, &noaction,
          "Don't start or stop the service", NULL },
        { NULL }
    };

    GOptionContext *context = g_option_context_new ("Options");
    g_option_context_add_main_entries (context, entries, NULL);
    if (! g_option_context_parse (context, &argc, &argv, NULL))
    {
        usage ();
        return 1;
    }
    g_option_context_free (context);

    /* help */
    if (argc >= 2 && !strcmp (argv[1], "help"))
    {
        usage ();
        return 0;
    }

    /* are we root? */
    if (getuid() != 0) {
        g_fprintf (stderr, _("You don't appear to be root. Exiting.\n"));
        return 1;
    }

    blacklist = services_blacklist_list ();

    if (argc >= 2 && !strcmp (argv[1], "list"))
    {
        g_printf (_("blacklisted services:\n"));
        GList *tmp = blacklist;
        g_list_foreach (tmp, print_item, NULL);
        return 0;
    }

    if (argc < 3)
    {
        usage ();
        return 1;
    }

    for (i=2;i<argc;i++)
    {
        if (!strcmp ("add", argv[1]))
            blacklist = services_blacklist_add (blacklist, argv[i], !noaction);

        else if (!strcmp ("del", argv[1]))
            blacklist = services_blacklist_del (blacklist, argv[i], !noaction);
    }

    services_blacklist_free (blacklist);

    return 0;
}
